# 12주 완성! AI 전문가 양성 과정: 파이썬부터 프로덕션 배포까지

![Course Banner](https://example.com/course_banner.png)  <!-- 이 부분은 나중에 적절한 이미지로 교체하세요 -->

"아이디어는 있는데, 어떻게 만들어야 할지 막막하신가요?"
"AI, 이제는 소비하는 것을 넘어 직접 만들고 싶으신가요?"

본 과정은 파이썬 기초 문법부터 시작하여, 실제 동작하는 AI 서비스를 직접 기획하고, 개발하며, 세상에 배포하는 전 과정을 경험하는 **12주 완성 실전형 AI 엔지니어링 코스**입니다. 막연한 아이디어를 현실로 만드는 '만들기 능력자'로 거듭나세요.

---

## 🚀 이 과정을 통해 얻을 수 있는 것

- **AI 서비스 개발의 A to Z**: 데이터 분석, 머신러닝/딥러닝 모델링, API 서버 개발, Docker를 이용한 배포까지, AI 제품 개발의 전체 사이클을 직접 경험하고 이해합니다.
- **실무 중심의 프로젝트 경험**: 9주간의 체계적인 학습 후, 3주간 나만의 개성이 담긴 **캡스톤 프로젝트**를 진행하며 현업 수준의 문제 해결 능력과 포트폴리오를 확보합니다.
- **생산성을 극대화하는 최신 기술 스택**: `FastAPI`, `Docker`, `PyTorch`, `LangChain` 등 현업에서 가장 수요가 높은 기술 스택을 사용합니다. `Cursor`, `GitHub Copilot` 같은 AI 네이티브 도구를 활용하여 개발 효율을 극대화하는 방법을 체득합니다.
- **지속 가능한 성장을 위한 발판**: MLOps의 기본 개념을 이해하고, 최신 AI 기술 트렌드를 읽는 눈을 기르며, AI 전문가로서 지속적으로 성장할 수 있는 학습 로드맵을 얻게 됩니다.

---

## 📚 전체 커리큘럼 개요

| 주차 (Week) | 주제 (Topic)                                               | 핵심 학습 내용                                                                                               | 바로가기                                                                         |
| :---------- | :--------------------------------------------------------- | :----------------------------------------------------------------------------------------------------------- | :------------------------------------------------------------------------------- |
| **Part 1**  | **1주차: AI 개발 환경 구축과 파이썬 기초 다지기**          | AI 개발에 필요한 최적의 환경(VSCode, Git)을 구축하고, 파이썬의 기본 자료형과 변수, 제어문을 익힙니다.             | [Part 1](./part_1_ai_development_environment.md) & [Part 2](./part_2_python_core_syntax.md) |
| **Part 2**  | **2주차: 파이썬 컬렉션과 객체 지향 프로그래밍(OOP) 입문**    | 리스트, 딕셔너리 등 데이터를 다루는 핵심 자료구조를 배우고, '붕어빵 비즈니스' 비유로 OOP의 개념을 이해합니다.       | [Part 3](./part_3_python_collections.md) & [Part 4](./part_4_object_oriented_programming.md) |
| **Part 3**  | **3주차: AI 핵심 라이브러리: NumPy & Pandas**              | '계란판' 비유로 NumPy의 배열 연산을, '엑셀'에 빗대어 Pandas의 데이터프레임 조작 및 분석 기술을 마스터합니다.       | [Part 5](./part_5_ai_core_libraries.md)                                          |
| **Part 4**  | **4주차: 머신러닝 입문과 Scikit-Learn**                    | 머신러닝의 전체 프로세스(데이터 전처리, 모델링, 평가)를 이해하고, Scikit-Learn으로 '타이타닉 생존자 예측' 실습을 진행합니다. | [Part 6](./part_6_machine_learning.md)                                           |
| **Part 5**  | **5주차: 딥러닝과 PyTorch 기초**                           | '레고 블록' 비유로 PyTorch의 작동 원리를 배우고, 딥러닝의 "Hello, World!"인 MNIST 손글씨 분류 모델을 구현합니다.   | [Part 7](./part_7_deep_learning.md)                                                |
| **Part 6**  | **6주차: LLM 애플리케이션 개발과 LangChain**               | '똑똑한 사서' 비유로 RAG의 개념을 이해하고, LangChain을 사용하여 간단한 Q&A 챗봇을 직접 만듭니다.               | [Part 7.5](./part_7.5_llm_application_development_with_langchain.md)             |
| **Part 7**  | **7주차: FastAPI를 이용한 AI 모델 서빙**                   | '맛집 레시피'인 AI 모델을 '레스토랑' API 서버로 만드는 과정을 배우고, Fashion-MNIST 모델을 API로 배포합니다.        | [Part 8](./part_8_model_serving_with_fastapi.md)                                 |
| **Part 8**  | **8주차: 프로덕션 레벨 API와 Docker**                      | '1인 식당'을 '프랜차이즈'로 확장하는 비유로 프로젝트를 구조화하고, Docker를 사용해 어디서든 동일하게 작동하는 서비스를 만듭니다. | [Part 9](./part_9_production_ready_api.md)                                       |
| **Part 9**  | **9주차: AI 전문가로 가는 길**                             | MLOps, AI 네이티브 IDE 등 전문가의 생산성 도구를 배우고, 최신 AI 트렌드를 바탕으로 다음 학습 로드맵을 설계합니다.     | [Part 10](./part_10_expert_path.md)                                              |
| **Part 10-12** | **10-12주차: 캡스톤 프로젝트**                             | 그동안 배운 모든 기술을 총동원하여 '나만의 AI 서비스'를 기획, 개발, 배포하고, 동료들에게 발표합니다.               | [Part 11](./part_11_capstone_project_guide.md)                                   |

---

## 🛠️ 기술 스택 (Tech Stack)

- **언어**: Python
- **핵심 라이브러리**: NumPy, Pandas, Scikit-learn, PyTorch, LangChain
- **API 서버**: FastAPI
- **배포 및 운영**: Docker, Git
- **개발 환경**: Visual Studio Code, Cursor, GitHub Copilot

---

## 📖 학습 자료

- **[전체 강의 계획서 (Course Schedule)](./AI_Expert_Course_Schedule.md)**: 12주 과정의 상세한 주차별 학습 목표와 내용을 확인하세요.
- **[파트별 용어집 (Glossaries)](./glossaries/)**: 과정 중에 등장하는 핵심 용어를 파트별로 다시 확인할 수 있습니다.
  - [Part 0: 과정 소개](./glossaries/part_0_glossary.md)
  - [Part 1: AI 개발 환경](./glossaries/part_1_glossary.md)
  - [Part 2: Python 핵심 문법](./glossaries/part_2_glossary.md)
  - [Part 3: Python 컬렉션](./glossaries/part_3_glossary.md)
  - [Part 4: 객체 지향 프로그래밍](./glossaries/part_4_glossary.md)
  - [Part 6: 머신러닝](./glossaries/part_6_glossary.md)
  - [Part 7: 딥러닝](./glossaries/part_7_glossary.md)
  - [Part 7.5: LangChain](./glossaries/part_7.5_glossary.md)
  - [Part 8: FastAPI](./glossaries/part_8_glossary.md)
  - [Part 9: Production-Ready API](./glossaries/part_9_glossary.md)
  - [Part 10: AI 전문가 과정](./glossaries/part_10_glossary.md)
  - [Part 11: 최종 프로젝트](./glossaries/part_11_glossary.md)
- **[실습 코드 모음 (Source Code)](./source_code/)**: 각 파트별 실습 코드를 직접 실행하고 수정해볼 수 있습니다.

> [!NOTE]
> 이 과정은 '금도'님의 AI 강의 자료를 기반으로, 수강생의 학습 경험 극대화를 위해 커리큘럼을 재구성하고 내용을 심화시킨 결과물입니다. 원작자의 훌륭한 비유와 설명에 깊이 감사합니다. 